"""
   /*
   **   Generated by blitz/resources/templates/combined.vm
   **
   **   Copyright 2007, 2008 Glencoe Software, Inc. All rights reserved.
   **   Use is subject to license terms supplied in LICENSE.txt
   **
   */
"""
try:
   unicode
except NameError:
   # Python 3: "unicode" is built-in
   unicode = str
import Ice
import IceImport
import omero
IceImport.load("omero_model_DetailsI")
IceImport.load("omero_model_Pixels_ice")
from omero.rtypes import rlong
from collections import namedtuple
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"
class PixelsI(_omero_model.Pixels):

      deprecations_warned = set()

      # Deprecation Warning
      @staticmethod
      def warn_of_deprecation(item):
          if item not in PixelsI.deprecations_warned:
              PixelsI.deprecations_warned.add(item)
              import warnings
              with warnings.catch_warnings():
                  warnings.simplefilter("always")
                  warnings.warn(item + " is deprecated", DeprecationWarning)

      # Property Metadata
      _field_info_data = namedtuple("FieldData", ["wrapper", "nullable"])
      _field_info_type = namedtuple("FieldInfo", [
          "image",
          "relatedTo",
          "pixelsType",
          "significantBits",
          "sizeX",
          "sizeY",
          "sizeZ",
          "sizeC",
          "sizeT",
          "sha1",
          "dimensionOrder",
          "physicalSizeX",
          "physicalSizeY",
          "physicalSizeZ",
          "waveStart",
          "waveIncrement",
          "timeIncrement",
          "methodology",
          "planeInfo",
          "pixelsFileMaps",
          "channels",
          "settings",
          "thumbnails",
          "details",
      ])
      _field_info = _field_info_type(
          image=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          relatedTo=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          pixelsType=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          significantBits=_field_info_data(wrapper=omero.rtypes.rint, nullable=True),
          sizeX=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          sizeY=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          sizeZ=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          sizeC=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          sizeT=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          sha1=_field_info_data(wrapper=omero.rtypes.rstring, nullable=False),
          dimensionOrder=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          physicalSizeX=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          physicalSizeY=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          physicalSizeZ=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          waveStart=_field_info_data(wrapper=omero.rtypes.rint, nullable=True),
          waveIncrement=_field_info_data(wrapper=omero.rtypes.rint, nullable=True),
          timeIncrement=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          methodology=_field_info_data(wrapper=omero.rtypes.rstring, nullable=True),
          planeInfo=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          pixelsFileMaps=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          channels=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          settings=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          thumbnails=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          details=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
      )  # end _field_info
      IMAGE =  "ome.model.core.Pixels_image"
      RELATEDTO =  "ome.model.core.Pixels_relatedTo"
      PIXELSTYPE =  "ome.model.core.Pixels_pixelsType"
      SIGNIFICANTBITS =  "ome.model.core.Pixels_significantBits"
      SIZEX =  "ome.model.core.Pixels_sizeX"
      SIZEY =  "ome.model.core.Pixels_sizeY"
      SIZEZ =  "ome.model.core.Pixels_sizeZ"
      SIZEC =  "ome.model.core.Pixels_sizeC"
      SIZET =  "ome.model.core.Pixels_sizeT"
      SHA1 =  "ome.model.core.Pixels_sha1"
      DIMENSIONORDER =  "ome.model.core.Pixels_dimensionOrder"
      PHYSICALSIZEX =  "ome.model.core.Pixels_physicalSizeX"
      PHYSICALSIZEY =  "ome.model.core.Pixels_physicalSizeY"
      PHYSICALSIZEZ =  "ome.model.core.Pixels_physicalSizeZ"
      WAVESTART =  "ome.model.core.Pixels_waveStart"
      WAVEINCREMENT =  "ome.model.core.Pixels_waveIncrement"
      TIMEINCREMENT =  "ome.model.core.Pixels_timeIncrement"
      METHODOLOGY =  "ome.model.core.Pixels_methodology"
      PLANEINFO =  "ome.model.core.Pixels_planeInfo"
      PIXELSFILEMAPS =  "ome.model.core.Pixels_pixelsFileMaps"
      CHANNELS =  "ome.model.core.Pixels_channels"
      SETTINGS =  "ome.model.core.Pixels_settings"
      THUMBNAILS =  "ome.model.core.Pixels_thumbnails"
      DETAILS =  "ome.model.core.Pixels_details"
      def errorIfUnloaded(self):
          if not self._loaded:
              raise _omero.UnloadedEntityException("Object unloaded:"+str(self))

      def throwNullCollectionException(self,propertyName):
          raise _omero.UnloadedEntityException(""+
          "Error updating collection:" + propertyName +"\n"+
          "Collection is currently null. This can be seen\n" +
          "by testing \""+ propertyName +"Loaded\". This implies\n"+
          "that this collection was unloaded. Please refresh this object\n"+
          "in order to update this collection.\n")

      def _toggleCollectionsLoaded(self, load):
          if load:
              self._planeInfoSeq = []
              self._planeInfoLoaded = True;
          else:
              self._planeInfoSeq = []
              self._planeInfoLoaded = False;

          if load:
              self._pixelsFileMapsSeq = []
              self._pixelsFileMapsLoaded = True;
          else:
              self._pixelsFileMapsSeq = []
              self._pixelsFileMapsLoaded = False;

          if load:
              self._channelsSeq = []
              self._channelsLoaded = True;
          else:
              self._channelsSeq = []
              self._channelsLoaded = False;

          if load:
              self._settingsSeq = []
              self._settingsLoaded = True;
          else:
              self._settingsSeq = []
              self._settingsLoaded = False;

          if load:
              self._thumbnailsSeq = []
              self._thumbnailsLoaded = True;
          else:
              self._thumbnailsSeq = []
              self._thumbnailsLoaded = False;

          pass

      def __init__(self, id=None, loaded=None):
          super(PixelsI, self).__init__()
          if id is not None and isinstance(id, (str, unicode)) and ":" in id:
              parts = id.split(":")
              if len(parts) != 2:
                  raise Exception("Invalid proxy string: %s", id)
              if parts[0] != self.__class__.__name__ and \
                 parts[0]+"I" != self.__class__.__name__:
                  raise Exception("Proxy class mismatch: %s<>%s" %
                  (self.__class__.__name__, parts[0]))
              self._id = rlong(parts[1])
              if loaded is None:
                  # If no loadedness was requested with
                  # a proxy string, then assume False.
                  loaded = False
          else:
              # Relying on omero.rtypes.rlong's error-handling
              self._id = rlong(id)
              if loaded is None:
                  loaded = True  # Assume true as previously
          self._loaded = loaded
          if self._loaded:
             self._details = _omero_model.DetailsI()
             self._toggleCollectionsLoaded(True)

      def unload(self, current = None):
          self._loaded = False
          self.unloadImage( )
          self.unloadRelatedTo( )
          self.unloadPixelsType( )
          self.unloadSignificantBits( )
          self.unloadSizeX( )
          self.unloadSizeY( )
          self.unloadSizeZ( )
          self.unloadSizeC( )
          self.unloadSizeT( )
          self.unloadSha1( )
          self.unloadDimensionOrder( )
          self.unloadPhysicalSizeX( )
          self.unloadPhysicalSizeY( )
          self.unloadPhysicalSizeZ( )
          self.unloadWaveStart( )
          self.unloadWaveIncrement( )
          self.unloadTimeIncrement( )
          self.unloadMethodology( )
          self.unloadPlaneInfo( )
          self.unloadPixelsFileMaps( )
          self.unloadChannels( )
          self.unloadSettings( )
          self.unloadThumbnails( )
          self.unloadDetails( )

      def isLoaded(self, current = None):
          return self._loaded
      def unloadCollections(self, current = None):
          self._toggleCollectionsLoaded( False )
      def isGlobal(self, current = None):
          return  False ;
      def isMutable(self, current = None):
          return  True ;
      def isAnnotated(self, current = None):
          return  False ;
      def isLink(self, current = None):
          return  False ;
      def shallowCopy(self, current = None):
            if not self._loaded: return self.proxy()
            copy = PixelsI()
            copy._id = self._id;
            copy._version = self._version;
            copy._details = None  # Unloading for the moment.
            raise omero.ClientError("NYI")
      def proxy(self, current = None):
          if self._id is None: raise omero.ClientError("Proxies require an id")
          return PixelsI( self._id.getValue(), False )

      def getDetails(self, current = None):
          self.errorIfUnloaded()
          return self._details

      def unloadDetails(self, current = None):
          self._details = None

      def getId(self, current = None):
          return self._id

      def setId(self, _id, current = None):
          self._id = _id

      def checkUnloadedProperty(self, value, loadedField):
          if value == None:
              self.__dict__[loadedField] = False
          else:
              self.__dict__[loadedField] = True

      def getVersion(self, current = None):
          self.errorIfUnloaded()
          return self._version

      def setVersion(self, version, current = None):
          self.errorIfUnloaded()
          self._version = version

      def unloadImage(self, ):
          self._imageLoaded = False
          self._image = None;

      def getImage(self, current = None):
          self.errorIfUnloaded()
          return self._image

      def setImage(self, _image, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.image.wrapper is not None:
              if _image is not None:
                  _image = self._field_info.image.wrapper(_image)
          self._image = _image
          pass

      def unloadRelatedTo(self, ):
          PixelsI.warn_of_deprecation("Pixels.relatedTo")
          self._relatedToLoaded = False
          self._relatedTo = None;

      def getRelatedTo(self, current = None):
          PixelsI.warn_of_deprecation("Pixels.relatedTo")
          self.errorIfUnloaded()
          return self._relatedTo

      def setRelatedTo(self, _relatedTo, current = None, wrap=False):
          PixelsI.warn_of_deprecation("Pixels.relatedTo")
          self.errorIfUnloaded()
          if wrap and self._field_info.relatedTo.wrapper is not None:
              if _relatedTo is not None:
                  _relatedTo = self._field_info.relatedTo.wrapper(_relatedTo)
          self._relatedTo = _relatedTo
          pass

      def unloadPixelsType(self, ):
          self._pixelsTypeLoaded = False
          self._pixelsType = None;

      def getPixelsType(self, current = None):
          self.errorIfUnloaded()
          return self._pixelsType

      def setPixelsType(self, _pixelsType, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.pixelsType.wrapper is not None:
              if _pixelsType is not None:
                  _pixelsType = self._field_info.pixelsType.wrapper(_pixelsType)
          self._pixelsType = _pixelsType
          pass

      def unloadSignificantBits(self, ):
          self._significantBitsLoaded = False
          self._significantBits = None;

      def getSignificantBits(self, current = None):
          self.errorIfUnloaded()
          return self._significantBits

      def setSignificantBits(self, _significantBits, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.significantBits.wrapper is not None:
              if _significantBits is not None:
                  _significantBits = self._field_info.significantBits.wrapper(_significantBits)
          self._significantBits = _significantBits
          pass

      def unloadSizeX(self, ):
          self._sizeXLoaded = False
          self._sizeX = None;

      def getSizeX(self, current = None):
          self.errorIfUnloaded()
          return self._sizeX

      def setSizeX(self, _sizeX, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.sizeX.wrapper is not None:
              if _sizeX is not None:
                  _sizeX = self._field_info.sizeX.wrapper(_sizeX)
          self._sizeX = _sizeX
          pass

      def unloadSizeY(self, ):
          self._sizeYLoaded = False
          self._sizeY = None;

      def getSizeY(self, current = None):
          self.errorIfUnloaded()
          return self._sizeY

      def setSizeY(self, _sizeY, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.sizeY.wrapper is not None:
              if _sizeY is not None:
                  _sizeY = self._field_info.sizeY.wrapper(_sizeY)
          self._sizeY = _sizeY
          pass

      def unloadSizeZ(self, ):
          self._sizeZLoaded = False
          self._sizeZ = None;

      def getSizeZ(self, current = None):
          self.errorIfUnloaded()
          return self._sizeZ

      def setSizeZ(self, _sizeZ, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.sizeZ.wrapper is not None:
              if _sizeZ is not None:
                  _sizeZ = self._field_info.sizeZ.wrapper(_sizeZ)
          self._sizeZ = _sizeZ
          pass

      def unloadSizeC(self, ):
          self._sizeCLoaded = False
          self._sizeC = None;

      def getSizeC(self, current = None):
          self.errorIfUnloaded()
          return self._sizeC

      def setSizeC(self, _sizeC, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.sizeC.wrapper is not None:
              if _sizeC is not None:
                  _sizeC = self._field_info.sizeC.wrapper(_sizeC)
          self._sizeC = _sizeC
          pass

      def unloadSizeT(self, ):
          self._sizeTLoaded = False
          self._sizeT = None;

      def getSizeT(self, current = None):
          self.errorIfUnloaded()
          return self._sizeT

      def setSizeT(self, _sizeT, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.sizeT.wrapper is not None:
              if _sizeT is not None:
                  _sizeT = self._field_info.sizeT.wrapper(_sizeT)
          self._sizeT = _sizeT
          pass

      def unloadSha1(self, ):
          self._sha1Loaded = False
          self._sha1 = None;

      def getSha1(self, current = None):
          self.errorIfUnloaded()
          return self._sha1

      def setSha1(self, _sha1, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.sha1.wrapper is not None:
              if _sha1 is not None:
                  _sha1 = self._field_info.sha1.wrapper(_sha1)
          self._sha1 = _sha1
          pass

      def unloadDimensionOrder(self, ):
          self._dimensionOrderLoaded = False
          self._dimensionOrder = None;

      def getDimensionOrder(self, current = None):
          self.errorIfUnloaded()
          return self._dimensionOrder

      def setDimensionOrder(self, _dimensionOrder, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.dimensionOrder.wrapper is not None:
              if _dimensionOrder is not None:
                  _dimensionOrder = self._field_info.dimensionOrder.wrapper(_dimensionOrder)
          self._dimensionOrder = _dimensionOrder
          pass

      def unloadPhysicalSizeX(self, ):
          self._physicalSizeXLoaded = False
          self._physicalSizeX = None;

      def getPhysicalSizeX(self, current = None):
          self.errorIfUnloaded()
          return self._physicalSizeX

      def setPhysicalSizeX(self, _physicalSizeX, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.physicalSizeX.wrapper is not None:
              if _physicalSizeX is not None:
                  _physicalSizeX = self._field_info.physicalSizeX.wrapper(_physicalSizeX)
          self._physicalSizeX = _physicalSizeX
          pass

      def unloadPhysicalSizeY(self, ):
          self._physicalSizeYLoaded = False
          self._physicalSizeY = None;

      def getPhysicalSizeY(self, current = None):
          self.errorIfUnloaded()
          return self._physicalSizeY

      def setPhysicalSizeY(self, _physicalSizeY, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.physicalSizeY.wrapper is not None:
              if _physicalSizeY is not None:
                  _physicalSizeY = self._field_info.physicalSizeY.wrapper(_physicalSizeY)
          self._physicalSizeY = _physicalSizeY
          pass

      def unloadPhysicalSizeZ(self, ):
          self._physicalSizeZLoaded = False
          self._physicalSizeZ = None;

      def getPhysicalSizeZ(self, current = None):
          self.errorIfUnloaded()
          return self._physicalSizeZ

      def setPhysicalSizeZ(self, _physicalSizeZ, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.physicalSizeZ.wrapper is not None:
              if _physicalSizeZ is not None:
                  _physicalSizeZ = self._field_info.physicalSizeZ.wrapper(_physicalSizeZ)
          self._physicalSizeZ = _physicalSizeZ
          pass

      def unloadWaveStart(self, ):
          self._waveStartLoaded = False
          self._waveStart = None;

      def getWaveStart(self, current = None):
          self.errorIfUnloaded()
          return self._waveStart

      def setWaveStart(self, _waveStart, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.waveStart.wrapper is not None:
              if _waveStart is not None:
                  _waveStart = self._field_info.waveStart.wrapper(_waveStart)
          self._waveStart = _waveStart
          pass

      def unloadWaveIncrement(self, ):
          self._waveIncrementLoaded = False
          self._waveIncrement = None;

      def getWaveIncrement(self, current = None):
          self.errorIfUnloaded()
          return self._waveIncrement

      def setWaveIncrement(self, _waveIncrement, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.waveIncrement.wrapper is not None:
              if _waveIncrement is not None:
                  _waveIncrement = self._field_info.waveIncrement.wrapper(_waveIncrement)
          self._waveIncrement = _waveIncrement
          pass

      def unloadTimeIncrement(self, ):
          self._timeIncrementLoaded = False
          self._timeIncrement = None;

      def getTimeIncrement(self, current = None):
          self.errorIfUnloaded()
          return self._timeIncrement

      def setTimeIncrement(self, _timeIncrement, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.timeIncrement.wrapper is not None:
              if _timeIncrement is not None:
                  _timeIncrement = self._field_info.timeIncrement.wrapper(_timeIncrement)
          self._timeIncrement = _timeIncrement
          pass

      def unloadMethodology(self, ):
          self._methodologyLoaded = False
          self._methodology = None;

      def getMethodology(self, current = None):
          self.errorIfUnloaded()
          return self._methodology

      def setMethodology(self, _methodology, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.methodology.wrapper is not None:
              if _methodology is not None:
                  _methodology = self._field_info.methodology.wrapper(_methodology)
          self._methodology = _methodology
          pass

      def unloadPlaneInfo(self, current = None):
          self._planeInfoLoaded = False
          self._planeInfoSeq = None;

      def _getPlaneInfo(self, current = None):
          self.errorIfUnloaded()
          return self._planeInfoSeq

      def _setPlaneInfo(self, _planeInfo, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.planeInfoSeq.wrapper is not None:
              if _planeInfo is not None:
                  _planeInfo = self._field_info.planeInfoSeq.wrapper(_planeInfo)
          self._planeInfoSeq = _planeInfo
          self.checkUnloadedProperty(_planeInfo,'planeInfoLoaded')

      def isPlaneInfoLoaded(self):
          return self._planeInfoLoaded

      def sizeOfPlaneInfo(self, current = None):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: return -1
          return len(self._planeInfoSeq)

      def copyPlaneInfo(self, current = None):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          return list(self._planeInfoSeq)

      def iteratePlaneInfo(self):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          return iter(self._planeInfoSeq)

      def addPlaneInfo(self, target, current = None):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          self._planeInfoSeq.append( target );
          target.setPixels( self )

      def addAllPlaneInfoSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          self._planeInfoSeq.extend( targets )
          for target in targets:
              target.setPixels( self )

      def removePlaneInfo(self, target, current = None):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          self._planeInfoSeq.remove( target )
          target.setPixels( None )

      def removeAllPlaneInfoSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          for elt in targets:
              elt.setPixels( None )
              self._planeInfoSeq.remove( elt )

      def clearPlaneInfo(self, current = None):
          self.errorIfUnloaded()
          if not self._planeInfoLoaded: self.throwNullCollectionException("planeInfoSeq")
          for elt in self._planeInfoSeq:
              elt.setPixels( None )
          self._planeInfoSeq = list()

      def reloadPlaneInfo(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._planeInfoLoaded:
              raise omero.ClientError("Cannot reload active collection: planeInfoSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyPlaneInfo() # May also throw
          for elt in copy:
              elt.setPixels( self )
          self._planeInfoSeq = copy
          toCopy.unloadPlaneInfo()
          self._planeInfoLoaded = True

      def unloadPixelsFileMaps(self, current = None):
          self._pixelsFileMapsLoaded = False
          self._pixelsFileMapsSeq = None;

      def _getPixelsFileMaps(self, current = None):
          self.errorIfUnloaded()
          return self._pixelsFileMapsSeq

      def _setPixelsFileMaps(self, _pixelsFileMaps, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.pixelsFileMapsSeq.wrapper is not None:
              if _pixelsFileMaps is not None:
                  _pixelsFileMaps = self._field_info.pixelsFileMapsSeq.wrapper(_pixelsFileMaps)
          self._pixelsFileMapsSeq = _pixelsFileMaps
          self.checkUnloadedProperty(_pixelsFileMaps,'pixelsFileMapsLoaded')

      def isPixelsFileMapsLoaded(self):
          return self._pixelsFileMapsLoaded

      def sizeOfPixelsFileMaps(self, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: return -1
          return len(self._pixelsFileMapsSeq)

      def copyPixelsFileMaps(self, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          return list(self._pixelsFileMapsSeq)

      def iteratePixelsFileMaps(self):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          return iter(self._pixelsFileMapsSeq)

      def addPixelsOriginalFileMap(self, target, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          self._pixelsFileMapsSeq.append( target );
          target.setChild( self )

      def addAllPixelsOriginalFileMapSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          self._pixelsFileMapsSeq.extend( targets )
          for target in targets:
              target.setChild( self )

      def removePixelsOriginalFileMap(self, target, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          self._pixelsFileMapsSeq.remove( target )
          target.setChild( None )

      def removeAllPixelsOriginalFileMapSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          for elt in targets:
              elt.setChild( None )
              self._pixelsFileMapsSeq.remove( elt )

      def clearPixelsFileMaps(self, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          for elt in self._pixelsFileMapsSeq:
              elt.setChild( None )
          self._pixelsFileMapsSeq = list()

      def reloadPixelsFileMaps(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._pixelsFileMapsLoaded:
              raise omero.ClientError("Cannot reload active collection: pixelsFileMapsSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyPixelsFileMaps() # May also throw
          for elt in copy:
              elt.setChild( self )
          self._pixelsFileMapsSeq = copy
          toCopy.unloadPixelsFileMaps()
          self._pixelsFileMapsLoaded = True

      def getPixelsFileMapsCountPerOwner(self, current = None):
          return self._pixelsFileMapsCountPerOwner

      def linkOriginalFile(self, addition, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          link = _omero_model.PixelsOriginalFileMapI()
          link.link( addition, self );
          self.addPixelsOriginalFileMapToBoth( link, True )
          return link

      def addPixelsOriginalFileMapToBoth(self, link, bothSides):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          self._pixelsFileMapsSeq.append( link )
          if bothSides and link.getParent().isLoaded():
              link.getParent().addPixelsOriginalFileMapToBoth( link, False )

      def findPixelsOriginalFileMap(self, removal, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          result = list()
          for link in self._pixelsFileMapsSeq:
              if link.getParent() == removal: result.append(link)
          return result

      def unlinkOriginalFile(self, removal, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          toRemove = self.findPixelsOriginalFileMap(removal)
          for next in toRemove:
              self.removePixelsOriginalFileMapFromBoth( next, True )

      def removePixelsOriginalFileMapFromBoth(self, link, bothSides, current = None):
          self.errorIfUnloaded()
          if not self._pixelsFileMapsLoaded: self.throwNullCollectionException("pixelsFileMapsSeq")
          self._pixelsFileMapsSeq.remove( link )
          if bothSides and link.getParent().isLoaded():
              link.getParent().removePixelsOriginalFileMapFromBoth(link, False)

      def linkedOriginalFileList(self, current = None):
          self.errorIfUnloaded()
          if not self.pixelsFileMapsLoaded: self.throwNullCollectionException("PixelsFileMaps")
          linked = []
          for link in self._pixelsFileMapsSeq:
              linked.append( link.getParent() )
          return linked

      def unloadChannels(self, current = None):
          self._channelsLoaded = False
          self._channelsSeq = None;

      def _getChannels(self, current = None):
          self.errorIfUnloaded()
          return self._channelsSeq

      def _setChannels(self, _channels, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.channelsSeq.wrapper is not None:
              if _channels is not None:
                  _channels = self._field_info.channelsSeq.wrapper(_channels)
          self._channelsSeq = _channels
          self.checkUnloadedProperty(_channels,'channelsLoaded')

      def isChannelsLoaded(self):
          return self._channelsLoaded

      def sizeOfChannels(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: return -1
          return len(self._channelsSeq)

      def copyChannels(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          return list(self._channelsSeq)

      def iterateChannels(self):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          return iter(self._channelsSeq)

      def addChannel(self, target, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          self._channelsSeq.append( target );
          target.setPixels( self )

      def addAllChannelSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          self._channelsSeq.extend( targets )
          for target in targets:
              target.setPixels( self )

      def removeChannel(self, target, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          self._channelsSeq.remove( target )
          target.setPixels( None )

      def removeAllChannelSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          for elt in targets:
              elt.setPixels( None )
              self._channelsSeq.remove( elt )

      def clearChannels(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          for elt in self._channelsSeq:
              elt.setPixels( None )
          self._channelsSeq = list()

      def reloadChannels(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._channelsLoaded:
              raise omero.ClientError("Cannot reload active collection: channelsSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyChannels() # May also throw
          for elt in copy:
              elt.setPixels( self )
          self._channelsSeq = copy
          toCopy.unloadChannels()
          self._channelsLoaded = True

      def getChannel(self, index, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          return self._channelsSeq[index]

      def setChannel(self, index, element, current = None, wrap=False):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          old = self._channelsSeq[index]
          if wrap and self._field_info.channelsSeq.wrapper is not None:
              if element is not None:
                  element = self._field_info.channelsSeq.wrapper(_channels)
          self._channelsSeq[index] =  element
          if element is not None and element.isLoaded():
              element.setPixels( self )
          return old

      def getPrimaryChannel(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          return self._channelsSeq[0]

      def setPrimaryChannel(self, element, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          index = self._channelsSeq.index(element)
          old = self._channelsSeq[0]
          self._channelsSeq[index] = old
          self._channelsSeq[0] = element
          return old

      def unloadSettings(self, current = None):
          self._settingsLoaded = False
          self._settingsSeq = None;

      def _getSettings(self, current = None):
          self.errorIfUnloaded()
          return self._settingsSeq

      def _setSettings(self, _settings, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.settingsSeq.wrapper is not None:
              if _settings is not None:
                  _settings = self._field_info.settingsSeq.wrapper(_settings)
          self._settingsSeq = _settings
          self.checkUnloadedProperty(_settings,'settingsLoaded')

      def isSettingsLoaded(self):
          return self._settingsLoaded

      def sizeOfSettings(self, current = None):
          self.errorIfUnloaded()
          if not self._settingsLoaded: return -1
          return len(self._settingsSeq)

      def copySettings(self, current = None):
          self.errorIfUnloaded()
          if not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          return list(self._settingsSeq)

      def iterateSettings(self):
          self.errorIfUnloaded()
          if not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          return iter(self._settingsSeq)

      def addRenderingDef(self, target, current = None):
          self.errorIfUnloaded()
          if not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          self._settingsSeq.append( target );
          target.setPixels( self )

      def addAllRenderingDefSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          self._settingsSeq.extend( targets )
          for target in targets:
              target.setPixels( self )

      def removeRenderingDef(self, target, current = None):
          self.errorIfUnloaded()
          if not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          self._settingsSeq.remove( target )
          target.setPixels( None )

      def removeAllRenderingDefSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          for elt in targets:
              elt.setPixels( None )
              self._settingsSeq.remove( elt )

      def clearSettings(self, current = None):
          self.errorIfUnloaded()
          if not self._settingsLoaded: self.throwNullCollectionException("settingsSeq")
          for elt in self._settingsSeq:
              elt.setPixels( None )
          self._settingsSeq = list()

      def reloadSettings(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._settingsLoaded:
              raise omero.ClientError("Cannot reload active collection: settingsSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copySettings() # May also throw
          for elt in copy:
              elt.setPixels( self )
          self._settingsSeq = copy
          toCopy.unloadSettings()
          self._settingsLoaded = True

      def unloadThumbnails(self, current = None):
          self._thumbnailsLoaded = False
          self._thumbnailsSeq = None;

      def _getThumbnails(self, current = None):
          self.errorIfUnloaded()
          return self._thumbnailsSeq

      def _setThumbnails(self, _thumbnails, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.thumbnailsSeq.wrapper is not None:
              if _thumbnails is not None:
                  _thumbnails = self._field_info.thumbnailsSeq.wrapper(_thumbnails)
          self._thumbnailsSeq = _thumbnails
          self.checkUnloadedProperty(_thumbnails,'thumbnailsLoaded')

      def isThumbnailsLoaded(self):
          return self._thumbnailsLoaded

      def sizeOfThumbnails(self, current = None):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: return -1
          return len(self._thumbnailsSeq)

      def copyThumbnails(self, current = None):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          return list(self._thumbnailsSeq)

      def iterateThumbnails(self):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          return iter(self._thumbnailsSeq)

      def addThumbnail(self, target, current = None):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          self._thumbnailsSeq.append( target );
          target.setPixels( self )

      def addAllThumbnailSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          self._thumbnailsSeq.extend( targets )
          for target in targets:
              target.setPixels( self )

      def removeThumbnail(self, target, current = None):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          self._thumbnailsSeq.remove( target )
          target.setPixels( None )

      def removeAllThumbnailSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          for elt in targets:
              elt.setPixels( None )
              self._thumbnailsSeq.remove( elt )

      def clearThumbnails(self, current = None):
          self.errorIfUnloaded()
          if not self._thumbnailsLoaded: self.throwNullCollectionException("thumbnailsSeq")
          for elt in self._thumbnailsSeq:
              elt.setPixels( None )
          self._thumbnailsSeq = list()

      def reloadThumbnails(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._thumbnailsLoaded:
              raise omero.ClientError("Cannot reload active collection: thumbnailsSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyThumbnails() # May also throw
          for elt in copy:
              elt.setPixels( self )
          self._thumbnailsSeq = copy
          toCopy.unloadThumbnails()
          self._thumbnailsLoaded = True


      def ice_postUnmarshal(self):
          """
          Provides additional initialization once all data loaded
          """
          pass # Currently unused


      def ice_preMarshal(self):
          """
          Provides additional validation before data is sent
          """
          pass # Currently unused

      def __getattr__(self, name):
          """
          Reroutes all access to object.field through object.getField() or object.isField()
          """
          if "_" in name:  # Ice disallows underscores, so these should be treated normally.
              return object.__getattribute__(self, name)
          field  = "_" + name
          capitalized = name[0].capitalize() + name[1:]
          getter = "get" + capitalized
          questn = "is" + capitalized
          try:
              self.__dict__[field]
              if hasattr(self, getter):
                  method = getattr(self, getter)
                  return method()
              elif hasattr(self, questn):
                  method = getattr(self, questn)
                  return method()
          except:
              pass
          raise AttributeError("'%s' object has no attribute '%s' or '%s'" % (self.__class__.__name__, getter, questn))

      def __setattr__(self, name, value):
          """
          Reroutes all access to object.field through object.getField(), with the caveat
          that all sets on variables starting with "_" are permitted directly.
          """
          if name.startswith("_"):
              self.__dict__[name] = value
              return
          else:
              field  = "_" + name
              setter = "set" + name[0].capitalize() + name[1:]
              if hasattr(self, field) and hasattr(self, setter):
                  method = getattr(self, setter)
                  return method(value)
          raise AttributeError("'%s' object has no attribute '%s'" % (self.__class__.__name__, setter))

_omero_model.PixelsI = PixelsI



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ModelF.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module omero
_M_omero = Ice.openModule('omero')
__name__ = 'omero'

# Start of module omero.model
_M_omero.model = Ice.openModule('omero.model')
__name__ = 'omero.model'

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Arc' not in _M_omero.model.__dict__:
    _M_omero.model._t_Arc = IcePy.declareClass('::omero::model::Arc')
    _M_omero.model._t_ArcPrx = IcePy.declareProxy('::omero::model::Arc')

if 'BooleanAnnotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_BooleanAnnotation = IcePy.declareClass('::omero::model::BooleanAnnotation')
    _M_omero.model._t_BooleanAnnotationPrx = IcePy.declareProxy('::omero::model::BooleanAnnotation')

if 'ChecksumAlgorithm' not in _M_omero.model.__dict__:
    _M_omero.model._t_ChecksumAlgorithm = IcePy.declareClass('::omero::model::ChecksumAlgorithm')
    _M_omero.model._t_ChecksumAlgorithmPrx = IcePy.declareProxy('::omero::model::ChecksumAlgorithm')

if 'Dataset' not in _M_omero.model.__dict__:
    _M_omero.model._t_Dataset = IcePy.declareClass('::omero::model::Dataset')
    _M_omero.model._t_DatasetPrx = IcePy.declareProxy('::omero::model::Dataset')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'Event' not in _M_omero.model.__dict__:
    _M_omero.model._t_Event = IcePy.declareClass('::omero::model::Event')
    _M_omero.model._t_EventPrx = IcePy.declareProxy('::omero::model::Event')

if 'EventLog' not in _M_omero.model.__dict__:
    _M_omero.model._t_EventLog = IcePy.declareClass('::omero::model::EventLog')
    _M_omero.model._t_EventLogPrx = IcePy.declareProxy('::omero::model::EventLog')

if 'Experimenter' not in _M_omero.model.__dict__:
    _M_omero.model._t_Experimenter = IcePy.declareClass('::omero::model::Experimenter')
    _M_omero.model._t_ExperimenterPrx = IcePy.declareProxy('::omero::model::Experimenter')

if 'ExperimenterGroup' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterGroup = IcePy.declareClass('::omero::model::ExperimenterGroup')
    _M_omero.model._t_ExperimenterGroupPrx = IcePy.declareProxy('::omero::model::ExperimenterGroup')

if 'ExternalInfo' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExternalInfo = IcePy.declareClass('::omero::model::ExternalInfo')
    _M_omero.model._t_ExternalInfoPrx = IcePy.declareProxy('::omero::model::ExternalInfo')

if 'Family' not in _M_omero.model.__dict__:
    _M_omero.model._t_Family = IcePy.declareClass('::omero::model::Family')
    _M_omero.model._t_FamilyPrx = IcePy.declareProxy('::omero::model::Family')

if 'Filament' not in _M_omero.model.__dict__:
    _M_omero.model._t_Filament = IcePy.declareClass('::omero::model::Filament')
    _M_omero.model._t_FilamentPrx = IcePy.declareProxy('::omero::model::Filament')

if 'Fileset' not in _M_omero.model.__dict__:
    _M_omero.model._t_Fileset = IcePy.declareClass('::omero::model::Fileset')
    _M_omero.model._t_FilesetPrx = IcePy.declareProxy('::omero::model::Fileset')

if 'FilesetJobLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_FilesetJobLink = IcePy.declareClass('::omero::model::FilesetJobLink')
    _M_omero.model._t_FilesetJobLinkPrx = IcePy.declareProxy('::omero::model::FilesetJobLink')

if 'Format' not in _M_omero.model.__dict__:
    _M_omero.model._t_Format = IcePy.declareClass('::omero::model::Format')
    _M_omero.model._t_FormatPrx = IcePy.declareProxy('::omero::model::Format')

if 'IObject' not in _M_omero.model.__dict__:
    _M_omero.model._t_IObject = IcePy.declareClass('::omero::model::IObject')
    _M_omero.model._t_IObjectPrx = IcePy.declareProxy('::omero::model::IObject')

if 'Image' not in _M_omero.model.__dict__:
    _M_omero.model._t_Image = IcePy.declareClass('::omero::model::Image')
    _M_omero.model._t_ImagePrx = IcePy.declareProxy('::omero::model::Image')

if 'Instrument' not in _M_omero.model.__dict__:
    _M_omero.model._t_Instrument = IcePy.declareClass('::omero::model::Instrument')
    _M_omero.model._t_InstrumentPrx = IcePy.declareProxy('::omero::model::Instrument')

if 'Job' not in _M_omero.model.__dict__:
    _M_omero.model._t_Job = IcePy.declareClass('::omero::model::Job')
    _M_omero.model._t_JobPrx = IcePy.declareProxy('::omero::model::Job')

if 'JobStatus' not in _M_omero.model.__dict__:
    _M_omero.model._t_JobStatus = IcePy.declareClass('::omero::model::JobStatus')
    _M_omero.model._t_JobStatusPrx = IcePy.declareProxy('::omero::model::JobStatus')

if 'Laser' not in _M_omero.model.__dict__:
    _M_omero.model._t_Laser = IcePy.declareClass('::omero::model::Laser')
    _M_omero.model._t_LaserPrx = IcePy.declareProxy('::omero::model::Laser')

if 'LogicalChannel' not in _M_omero.model.__dict__:
    _M_omero.model._t_LogicalChannel = IcePy.declareClass('::omero::model::LogicalChannel')
    _M_omero.model._t_LogicalChannelPrx = IcePy.declareProxy('::omero::model::LogicalChannel')

if 'NamedValue' not in _M_omero.model.__dict__:
    _M_omero.model._t_NamedValue = IcePy.declareClass('::omero::model::NamedValue')
    _M_omero.model._t_NamedValuePrx = IcePy.declareProxy('::omero::model::NamedValue')

if 'OriginalFile' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFile = IcePy.declareClass('::omero::model::OriginalFile')
    _M_omero.model._t_OriginalFilePrx = IcePy.declareProxy('::omero::model::OriginalFile')

if 'Permissions' not in _M_omero.model.__dict__:
    _M_omero.model._t_Permissions = IcePy.declareClass('::omero::model::Permissions')
    _M_omero.model._t_PermissionsPrx = IcePy.declareProxy('::omero::model::Permissions')

if 'Pixels' not in _M_omero.model.__dict__:
    _M_omero.model._t_Pixels = IcePy.declareClass('::omero::model::Pixels')
    _M_omero.model._t_PixelsPrx = IcePy.declareProxy('::omero::model::Pixels')

if 'PixelsType' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsType = IcePy.declareClass('::omero::model::PixelsType')
    _M_omero.model._t_PixelsTypePrx = IcePy.declareProxy('::omero::model::PixelsType')

if 'PlaneInfo' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlaneInfo = IcePy.declareClass('::omero::model::PlaneInfo')
    _M_omero.model._t_PlaneInfoPrx = IcePy.declareProxy('::omero::model::PlaneInfo')

if 'Plate' not in _M_omero.model.__dict__:
    _M_omero.model._t_Plate = IcePy.declareClass('::omero::model::Plate')
    _M_omero.model._t_PlatePrx = IcePy.declareProxy('::omero::model::Plate')

if 'Project' not in _M_omero.model.__dict__:
    _M_omero.model._t_Project = IcePy.declareClass('::omero::model::Project')
    _M_omero.model._t_ProjectPrx = IcePy.declareProxy('::omero::model::Project')

if 'QuantumDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_QuantumDef = IcePy.declareClass('::omero::model::QuantumDef')
    _M_omero.model._t_QuantumDefPrx = IcePy.declareProxy('::omero::model::QuantumDef')

if 'RenderingDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDef = IcePy.declareClass('::omero::model::RenderingDef')
    _M_omero.model._t_RenderingDefPrx = IcePy.declareProxy('::omero::model::RenderingDef')

if 'RenderingModel' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingModel = IcePy.declareClass('::omero::model::RenderingModel')
    _M_omero.model._t_RenderingModelPrx = IcePy.declareProxy('::omero::model::RenderingModel')

if 'Roi' not in _M_omero.model.__dict__:
    _M_omero.model._t_Roi = IcePy.declareClass('::omero::model::Roi')
    _M_omero.model._t_RoiPrx = IcePy.declareProxy('::omero::model::Roi')

if 'Screen' not in _M_omero.model.__dict__:
    _M_omero.model._t_Screen = IcePy.declareClass('::omero::model::Screen')
    _M_omero.model._t_ScreenPrx = IcePy.declareProxy('::omero::model::Screen')

if 'ScriptJob' not in _M_omero.model.__dict__:
    _M_omero.model._t_ScriptJob = IcePy.declareClass('::omero::model::ScriptJob')
    _M_omero.model._t_ScriptJobPrx = IcePy.declareProxy('::omero::model::ScriptJob')

if 'Shape' not in _M_omero.model.__dict__:
    _M_omero.model._t_Shape = IcePy.declareClass('::omero::model::Shape')
    _M_omero.model._t_ShapePrx = IcePy.declareProxy('::omero::model::Shape')

if 'Session' not in _M_omero.model.__dict__:
    _M_omero.model._t_Session = IcePy.declareClass('::omero::model::Session')
    _M_omero.model._t_SessionPrx = IcePy.declareProxy('::omero::model::Session')

if 'Share' not in _M_omero.model.__dict__:
    _M_omero.model._t_Share = IcePy.declareClass('::omero::model::Share')
    _M_omero.model._t_SharePrx = IcePy.declareProxy('::omero::model::Share')

if 'TextAnnotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_TextAnnotation = IcePy.declareClass('::omero::model::TextAnnotation')
    _M_omero.model._t_TextAnnotationPrx = IcePy.declareProxy('::omero::model::TextAnnotation')

if 'Well' not in _M_omero.model.__dict__:
    _M_omero.model._t_Well = IcePy.declareClass('::omero::model::Well')
    _M_omero.model._t_WellPrx = IcePy.declareProxy('::omero::model::Well')

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Reagent.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Screen' not in _M_omero.model.__dict__:
    _M_omero.model._t_Screen = IcePy.declareClass('::omero::model::Screen')
    _M_omero.model._t_ScreenPrx = IcePy.declareProxy('::omero::model::Screen')

if 'WellReagentLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_WellReagentLink = IcePy.declareClass('::omero::model::WellReagentLink')
    _M_omero.model._t_WellReagentLinkPrx = IcePy.declareProxy('::omero::model::WellReagentLink')

if 'Well' not in _M_omero.model.__dict__:
    _M_omero.model._t_Well = IcePy.declareClass('::omero::model::Well')
    _M_omero.model._t_WellPrx = IcePy.declareProxy('::omero::model::Well')

if 'ReagentAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ReagentAnnotationLink = IcePy.declareClass('::omero::model::ReagentAnnotationLink')
    _M_omero.model._t_ReagentAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ReagentAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ReagentWellLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ReagentWellLinksSeq = IcePy.defineSequence('::omero::model::ReagentWellLinksSeq', (), _M_omero.model._t_WellReagentLink)

if '_t_ReagentLinkedWellSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ReagentLinkedWellSeq = IcePy.defineSequence('::omero::model::ReagentLinkedWellSeq', (), _M_omero.model._t_Well)

if '_t_ReagentAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ReagentAnnotationLinksSeq = IcePy.defineSequence('::omero::model::ReagentAnnotationLinksSeq', (), _M_omero.model._t_ReagentAnnotationLink)

if '_t_ReagentLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ReagentLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::ReagentLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Reagent' not in _M_omero.model.__dict__:
    _M_omero.model.Reagent = Ice.createTempClass()
    class Reagent(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _name=None, _reagentIdentifier=None, _screen=None, _wellLinksSeq=None, _wellLinksLoaded=False, _wellLinksCountPerOwner=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _description=None):
            if Ice.getType(self) == _M_omero.model.Reagent:
                raise RuntimeError('omero.model.Reagent is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._name = _name
            self._reagentIdentifier = _reagentIdentifier
            self._screen = _screen
            self._wellLinksSeq = _wellLinksSeq
            self._wellLinksLoaded = _wellLinksLoaded
            self._wellLinksCountPerOwner = _wellLinksCountPerOwner
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Reagent')

        def ice_id(self, current=None):
            return '::omero::model::Reagent'

        def ice_staticId():
            return '::omero::model::Reagent'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getReagentIdentifier(self, current=None):
            pass

        def setReagentIdentifier(self, theReagentIdentifier, current=None):
            pass

        def getScreen(self, current=None):
            pass

        def setScreen(self, theScreen, current=None):
            pass

        def unloadWellLinks(self, current=None):
            pass

        def sizeOfWellLinks(self, current=None):
            pass

        def copyWellLinks(self, current=None):
            pass

        def addWellReagentLink(self, target, current=None):
            pass

        def addAllWellReagentLinkSet(self, targets, current=None):
            pass

        def removeWellReagentLink(self, theTarget, current=None):
            pass

        def removeAllWellReagentLinkSet(self, targets, current=None):
            pass

        def clearWellLinks(self, current=None):
            pass

        def reloadWellLinks(self, toCopy, current=None):
            pass

        def getWellLinksCountPerOwner(self, current=None):
            pass

        def linkWell(self, addition, current=None):
            pass

        def addWellReagentLinkToBoth(self, link, bothSides, current=None):
            pass

        def findWellReagentLink(self, removal, current=None):
            pass

        def unlinkWell(self, removal, current=None):
            pass

        def removeWellReagentLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedWellList(self, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addReagentAnnotationLink(self, target, current=None):
            pass

        def addAllReagentAnnotationLinkSet(self, targets, current=None):
            pass

        def removeReagentAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllReagentAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addReagentAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findReagentAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeReagentAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Reagent)

        __repr__ = __str__

    _M_omero.model.ReagentPrx = Ice.createTempClass()
    class ReagentPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Reagent._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Reagent._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Reagent._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Reagent._op_setVersion.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.Reagent._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.Reagent._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.Reagent._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.Reagent._op_setName.end(self, _r)

        def getReagentIdentifier(self, _ctx=None):
            return _M_omero.model.Reagent._op_getReagentIdentifier.invoke(self, ((), _ctx))

        def begin_getReagentIdentifier(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getReagentIdentifier.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getReagentIdentifier(self, _r):
            return _M_omero.model.Reagent._op_getReagentIdentifier.end(self, _r)

        def setReagentIdentifier(self, theReagentIdentifier, _ctx=None):
            return _M_omero.model.Reagent._op_setReagentIdentifier.invoke(self, ((theReagentIdentifier, ), _ctx))

        def begin_setReagentIdentifier(self, theReagentIdentifier, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_setReagentIdentifier.begin(self, ((theReagentIdentifier, ), _response, _ex, _sent, _ctx))

        def end_setReagentIdentifier(self, _r):
            return _M_omero.model.Reagent._op_setReagentIdentifier.end(self, _r)

        def getScreen(self, _ctx=None):
            return _M_omero.model.Reagent._op_getScreen.invoke(self, ((), _ctx))

        def begin_getScreen(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getScreen.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getScreen(self, _r):
            return _M_omero.model.Reagent._op_getScreen.end(self, _r)

        def setScreen(self, theScreen, _ctx=None):
            return _M_omero.model.Reagent._op_setScreen.invoke(self, ((theScreen, ), _ctx))

        def begin_setScreen(self, theScreen, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_setScreen.begin(self, ((theScreen, ), _response, _ex, _sent, _ctx))

        def end_setScreen(self, _r):
            return _M_omero.model.Reagent._op_setScreen.end(self, _r)

        def unloadWellLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_unloadWellLinks.invoke(self, ((), _ctx))

        def begin_unloadWellLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_unloadWellLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadWellLinks(self, _r):
            return _M_omero.model.Reagent._op_unloadWellLinks.end(self, _r)

        def sizeOfWellLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_sizeOfWellLinks.invoke(self, ((), _ctx))

        def begin_sizeOfWellLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_sizeOfWellLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfWellLinks(self, _r):
            return _M_omero.model.Reagent._op_sizeOfWellLinks.end(self, _r)

        def copyWellLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_copyWellLinks.invoke(self, ((), _ctx))

        def begin_copyWellLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_copyWellLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyWellLinks(self, _r):
            return _M_omero.model.Reagent._op_copyWellLinks.end(self, _r)

        def addWellReagentLink(self, target, _ctx=None):
            return _M_omero.model.Reagent._op_addWellReagentLink.invoke(self, ((target, ), _ctx))

        def begin_addWellReagentLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_addWellReagentLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addWellReagentLink(self, _r):
            return _M_omero.model.Reagent._op_addWellReagentLink.end(self, _r)

        def addAllWellReagentLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Reagent._op_addAllWellReagentLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllWellReagentLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_addAllWellReagentLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllWellReagentLinkSet(self, _r):
            return _M_omero.model.Reagent._op_addAllWellReagentLinkSet.end(self, _r)

        def removeWellReagentLink(self, theTarget, _ctx=None):
            return _M_omero.model.Reagent._op_removeWellReagentLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeWellReagentLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_removeWellReagentLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeWellReagentLink(self, _r):
            return _M_omero.model.Reagent._op_removeWellReagentLink.end(self, _r)

        def removeAllWellReagentLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Reagent._op_removeAllWellReagentLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllWellReagentLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_removeAllWellReagentLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllWellReagentLinkSet(self, _r):
            return _M_omero.model.Reagent._op_removeAllWellReagentLinkSet.end(self, _r)

        def clearWellLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_clearWellLinks.invoke(self, ((), _ctx))

        def begin_clearWellLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_clearWellLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearWellLinks(self, _r):
            return _M_omero.model.Reagent._op_clearWellLinks.end(self, _r)

        def reloadWellLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Reagent._op_reloadWellLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadWellLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_reloadWellLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadWellLinks(self, _r):
            return _M_omero.model.Reagent._op_reloadWellLinks.end(self, _r)

        def getWellLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Reagent._op_getWellLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getWellLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getWellLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWellLinksCountPerOwner(self, _r):
            return _M_omero.model.Reagent._op_getWellLinksCountPerOwner.end(self, _r)

        def linkWell(self, addition, _ctx=None):
            return _M_omero.model.Reagent._op_linkWell.invoke(self, ((addition, ), _ctx))

        def begin_linkWell(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_linkWell.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkWell(self, _r):
            return _M_omero.model.Reagent._op_linkWell.end(self, _r)

        def addWellReagentLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Reagent._op_addWellReagentLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addWellReagentLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_addWellReagentLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addWellReagentLinkToBoth(self, _r):
            return _M_omero.model.Reagent._op_addWellReagentLinkToBoth.end(self, _r)

        def findWellReagentLink(self, removal, _ctx=None):
            return _M_omero.model.Reagent._op_findWellReagentLink.invoke(self, ((removal, ), _ctx))

        def begin_findWellReagentLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_findWellReagentLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findWellReagentLink(self, _r):
            return _M_omero.model.Reagent._op_findWellReagentLink.end(self, _r)

        def unlinkWell(self, removal, _ctx=None):
            return _M_omero.model.Reagent._op_unlinkWell.invoke(self, ((removal, ), _ctx))

        def begin_unlinkWell(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_unlinkWell.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkWell(self, _r):
            return _M_omero.model.Reagent._op_unlinkWell.end(self, _r)

        def removeWellReagentLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Reagent._op_removeWellReagentLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeWellReagentLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_removeWellReagentLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeWellReagentLinkFromBoth(self, _r):
            return _M_omero.model.Reagent._op_removeWellReagentLinkFromBoth.end(self, _r)

        def linkedWellList(self, _ctx=None):
            return _M_omero.model.Reagent._op_linkedWellList.invoke(self, ((), _ctx))

        def begin_linkedWellList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_linkedWellList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedWellList(self, _r):
            return _M_omero.model.Reagent._op_linkedWellList.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Reagent._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Reagent._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Reagent._op_copyAnnotationLinks.end(self, _r)

        def addReagentAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Reagent._op_addReagentAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addReagentAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_addReagentAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addReagentAnnotationLink(self, _r):
            return _M_omero.model.Reagent._op_addReagentAnnotationLink.end(self, _r)

        def addAllReagentAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Reagent._op_addAllReagentAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllReagentAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_addAllReagentAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllReagentAnnotationLinkSet(self, _r):
            return _M_omero.model.Reagent._op_addAllReagentAnnotationLinkSet.end(self, _r)

        def removeReagentAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Reagent._op_removeReagentAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeReagentAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_removeReagentAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeReagentAnnotationLink(self, _r):
            return _M_omero.model.Reagent._op_removeReagentAnnotationLink.end(self, _r)

        def removeAllReagentAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Reagent._op_removeAllReagentAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllReagentAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_removeAllReagentAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllReagentAnnotationLinkSet(self, _r):
            return _M_omero.model.Reagent._op_removeAllReagentAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Reagent._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Reagent._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Reagent._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Reagent._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Reagent._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Reagent._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Reagent._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Reagent._op_linkAnnotation.end(self, _r)

        def addReagentAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Reagent._op_addReagentAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addReagentAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_addReagentAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addReagentAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Reagent._op_addReagentAnnotationLinkToBoth.end(self, _r)

        def findReagentAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Reagent._op_findReagentAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findReagentAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_findReagentAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findReagentAnnotationLink(self, _r):
            return _M_omero.model.Reagent._op_findReagentAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Reagent._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Reagent._op_unlinkAnnotation.end(self, _r)

        def removeReagentAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Reagent._op_removeReagentAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeReagentAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_removeReagentAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeReagentAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Reagent._op_removeReagentAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Reagent._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Reagent._op_linkedAnnotationList.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Reagent._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Reagent._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Reagent._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Reagent._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Reagent._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ReagentPrx.ice_checkedCast(proxy, '::omero::model::Reagent', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ReagentPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Reagent'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ReagentPrx = IcePy.defineProxy('::omero::model::Reagent', ReagentPrx)

    _M_omero.model._t_Reagent = IcePy.declareClass('::omero::model::Reagent')

    _M_omero.model._t_Reagent = IcePy.defineClass('::omero::model::Reagent', Reagent, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_reagentIdentifier', (), _M_omero._t_RString, False, 0),
        ('_screen', (), _M_omero.model._t_Screen, False, 0),
        ('_wellLinksSeq', (), _M_omero.model._t_ReagentWellLinksSeq, False, 0),
        ('_wellLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_wellLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_ReagentAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    Reagent._ice_type = _M_omero.model._t_Reagent

    Reagent._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Reagent._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Reagent._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Reagent._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Reagent._op_getReagentIdentifier = IcePy.Operation('getReagentIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Reagent._op_setReagentIdentifier = IcePy.Operation('setReagentIdentifier', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Reagent._op_getScreen = IcePy.Operation('getScreen', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Screen, False, 0), ())
    Reagent._op_setScreen = IcePy.Operation('setScreen', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Screen, False, 0),), (), None, ())
    Reagent._op_unloadWellLinks = IcePy.Operation('unloadWellLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Reagent._op_sizeOfWellLinks = IcePy.Operation('sizeOfWellLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Reagent._op_copyWellLinks = IcePy.Operation('copyWellLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ReagentWellLinksSeq, False, 0), ())
    Reagent._op_addWellReagentLink = IcePy.Operation('addWellReagentLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_WellReagentLink, False, 0),), (), None, ())
    Reagent._op_addAllWellReagentLinkSet = IcePy.Operation('addAllWellReagentLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentWellLinksSeq, False, 0),), (), None, ())
    Reagent._op_removeWellReagentLink = IcePy.Operation('removeWellReagentLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_WellReagentLink, False, 0),), (), None, ())
    Reagent._op_removeAllWellReagentLinkSet = IcePy.Operation('removeAllWellReagentLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentWellLinksSeq, False, 0),), (), None, ())
    Reagent._op_clearWellLinks = IcePy.Operation('clearWellLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Reagent._op_reloadWellLinks = IcePy.Operation('reloadWellLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Reagent, False, 0),), (), None, ())
    Reagent._op_getWellLinksCountPerOwner = IcePy.Operation('getWellLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Reagent._op_linkWell = IcePy.Operation('linkWell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Well, False, 0),), (), ((), _M_omero.model._t_WellReagentLink, False, 0), ())
    Reagent._op_addWellReagentLinkToBoth = IcePy.Operation('addWellReagentLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_WellReagentLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Reagent._op_findWellReagentLink = IcePy.Operation('findWellReagentLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Well, False, 0),), (), ((), _M_omero.model._t_ReagentWellLinksSeq, False, 0), ())
    Reagent._op_unlinkWell = IcePy.Operation('unlinkWell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Well, False, 0),), (), None, ())
    Reagent._op_removeWellReagentLinkFromBoth = IcePy.Operation('removeWellReagentLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_WellReagentLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Reagent._op_linkedWellList = IcePy.Operation('linkedWellList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ReagentLinkedWellSeq, False, 0), ())
    Reagent._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Reagent._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Reagent._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ReagentAnnotationLinksSeq, False, 0), ())
    Reagent._op_addReagentAnnotationLink = IcePy.Operation('addReagentAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentAnnotationLink, False, 0),), (), None, ())
    Reagent._op_addAllReagentAnnotationLinkSet = IcePy.Operation('addAllReagentAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentAnnotationLinksSeq, False, 0),), (), None, ())
    Reagent._op_removeReagentAnnotationLink = IcePy.Operation('removeReagentAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentAnnotationLink, False, 0),), (), None, ())
    Reagent._op_removeAllReagentAnnotationLinkSet = IcePy.Operation('removeAllReagentAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentAnnotationLinksSeq, False, 0),), (), None, ())
    Reagent._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Reagent._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Reagent, False, 0),), (), None, ())
    Reagent._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Reagent._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ReagentAnnotationLink, False, 0), ())
    Reagent._op_addReagentAnnotationLinkToBoth = IcePy.Operation('addReagentAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Reagent._op_findReagentAnnotationLink = IcePy.Operation('findReagentAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ReagentAnnotationLinksSeq, False, 0), ())
    Reagent._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Reagent._op_removeReagentAnnotationLinkFromBoth = IcePy.Operation('removeReagentAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ReagentAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Reagent._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ReagentLinkedAnnotationSeq, False, 0), ())
    Reagent._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Reagent._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Reagent = Reagent
    del Reagent

    _M_omero.model.ReagentPrx = ReagentPrx
    del ReagentPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
